@@ -5,7 +5,7 @@
 %%% Created : 6 Jan 2011 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -47,28 +47,30 @@
 -record(state, {type = udp :: udp | tcp | tls,
 		addr       :: addr(),
 		peer       :: addr(),
-		sock       :: port(),
+		sock       :: fast_tls:tls_socket(),
 		buf = <<>> :: binary(),
 		max_size   :: non_neg_integer(),
-		msg        :: #sip{},
+		msg        :: #sip{} | undefined,
 		wait_size  :: non_neg_integer(),
 		certfile   :: iodata()}).
 
+-dialyzer({no_match, [init/1, handle_info/2, process_data/2]}).
+
 %%%===================================================================
 %%% API
 %%%===================================================================
 %% @doc Start TCP client to connect
 start_link() ->
-    ?GEN_SERVER:start_link(?MODULE, [], [{max_queue, 5000}]).
+    ?GEN_SERVER:start_link(?MODULE, [], []).
 
 %% @doc Start UDP worker
 start_link(I) ->
     ?GEN_SERVER:start_link({local, get_proc(I)}, ?MODULE, [],
-			   [{max_queue, 5000}]).
+			   []).
 
 %% @doc Start TCP acceptor
 start_link(Sock, Opts) ->
-    ?GEN_SERVER:start_link(?MODULE, [Sock, Opts], [{max_queue, 5000}]).
+    ?GEN_SERVER:start_link(?MODULE, [Sock, Opts], []).
 
 %% @doc Start TCP client to connect, the callback
 start() ->
